@@ -130,7 +130,7 @@ class JsonableAnswer(Answer):
         if hasattr(cls, _FIXED_PAYLOAD_TYPE__NAME):
             return getattr(cls, _FIXED_PAYLOAD_TYPE__NAME)
 
-    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, None]) -> type:
+    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType]) -> type:
         if isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
@@ -149,9 +149,9 @@ class WrappedAnswer(JsonableAnswer):
         attribute_key_to_type = {"done": bool, "result": type_} if type_ not  in (None, type[None]) else {"done": bool}
         return create_dataclass(_prepare_class_name([type_],  "Wrapped"), [cls], attribute_key_to_type)
 
-    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type]) -> type:
+    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
         type_origin = getattr(modifier, '__origin__', None)
-        if type_origin or isinstance(modifier, type):
+        if type_origin or isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
             wrapped_type = cls._wrap_type(modifier)
